// -*- C++ -*-
/*!
 * @file  ShmScheduler.cpp * @brief Scheduler component * $Date$ 
 *
 * $Id$ 
 */
#include "ShmScheduler.h"

// Module specification
// <rtc-template block="module_spec">
static const char* shmscheduler_spec[] =
  {
    "implementation_id", "ShmScheduler",
    "type_name",         "ShmScheduler",
    "description",       "Scheduler component",
    "version",           "0.1",
    "vendor",            "TIRI",
    "category",          "Generic",
    "activity_type",     "PERIODIC",
    "kind",              "ShmScheduler",
    "max_instance",      "10",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    ""
  };
// </rtc-template>

ShmScheduler::ShmScheduler(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager)
    // </rtc-template>
{
  std::string prefix = "schedIn";
  for(size_t i = 0; i < NUM_SCHED_IN_PORTS; i++){
    std::string portName = prefix + char(i + '0');
    m_inPortList.push_back(boost::make_shared<ShmSchedInPort>(portName.c_str()));
  }
}

ShmScheduler::~ShmScheduler()
{
  
}


RTC::ReturnCode_t ShmScheduler::onInitialize()
{
  for(SchedInPortList::iterator i = m_inPortList.begin(); i != m_inPortList.end(); i++){
    (*i)->attachTo(*this);
  }
  
  return RTC::RTC_OK;
}


/*
RTC::ReturnCode_t ShmScheduler::onFinalize()
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onExecute(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t ShmScheduler::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


extern "C"
{
 
  void ShmSchedulerInit(RTC::Manager* manager)
  {
    coil::Properties profile(shmscheduler_spec);
    manager->registerFactory(profile,
                             RTC::Create<ShmScheduler>,
                             RTC::Delete<ShmScheduler>);
  }
  
};



