#ifndef SHM_BUFFER_HPP
#define SHM_BUFFER_HPP

#include <boost/interprocess/managed_shared_memory.hpp>
#include <boost/interprocess/containers/deque.hpp>
#include <boost/interprocess/allocators/allocator.hpp>

/**
 *
 * インスタンスを共有メモリに配置するのでメンバ関数への virtual指定は不可
 *  --> 仮想関数テーブルvtableのアドレス解決ができずに不可解な SEGVの原因になる
 */
template<typename T>
class ShmBuffer
{
public:
  ShmBuffer(boost::interprocess::managed_shared_memory* shmSegment, size_t maxBufferSize);
  ~ShmBuffer();
  bool write(const T& value);
  bool read(T& readVal);
  T& front();
  
  // const T& reference() const;
  bool isEmpty();


private:
  typedef boost::interprocess::managed_shared_memory ShMem;
  typedef boost::interprocess::allocator<T, ShMem::segment_manager> ShmAllocator;
  typedef boost::interprocess::deque<T, ShmAllocator> ShmDeque;
  typedef boost::interprocess::interprocess_mutex ShmMutex;  
  ShmBuffer(const ShmBuffer<T>& other); // privateにして意図しないコピーを防ぐ
  ShmBuffer(); // privateにして意図しないコピーを防ぐ

  ShMem* m_shmSegment; //* 共有メモリ領域オブジェクト
  ShmAllocator m_allocator;
  ShmMutex m_mutex;

  boost::interprocess::offset_ptr<ShmDeque> m_buffOffset;
  size_t m_maxBufferSize;
};

#include "ShmBuffer_primitive.hpp"

#endif // SHM_BUFFER_HPP

