#ifndef SHM_IN_PORT_HPP
#define SHM_IN_PORT_HPP

#include <boost/interprocess/managed_shared_memory.hpp>
#include <rtm/DataFlowComponentBase.h>
#include <shmport/idl/ShmPortStub.h>

template<typename T> class ShmBuffer;

template<typename T>
class ShmInPort //  : public rtm::InPortBase
{
public:
  ShmInPort(const char *portName, T& boundVar);
  ~ShmInPort();

  virtual void attachTo(RTC::DataFlowComponentBase& rtc);
  //virtual T read();
  virtual bool read();
  virtual bool isNew();
  virtual bool peek(T& retVal);
  
private:
  virtual void open();
  virtual bool openShmSegment(const char *segmentID);
  virtual bool findInstance(const char *instanceID);
  virtual void closeShmSegment();
  
  boost::interprocess::managed_shared_memory& shmSegment(const std::string& segmentID);
  std::string m_name;
  boost::interprocess::managed_shared_memory* m_shmSegment;
  ShmBuffer<T> *m_shmBuffer;
  RTC::CorbaPort m_servicePort;
  RTC::CorbaConsumer<ShmPort::ShmPortService> m_consumer;
  T& m_boundVar;
  
  class ActivationListener; 
  class DeactivationListener;
};

#include "ShmInPort_primitive.hpp"
#endif // SHM_IN_PORT_HPP
