// -*- C++ -*-
/*!
 * @file  PIDController.cpp * @brief  * $Date$ 
 *
 * $Id$ 
 */
#include "PIDController.h"

// Module specification
// <rtc-template block="module_spec">
static const char* pidcontroller_spec[] =
  {
    "implementation_id", "PIDController",
    "type_name",         "PIDController",
    "description",       "",
    "version",           "0.1",
    "vendor",            "TIRI",
    "category",          "Generic",
    "activity_type",     "PERIODIC",
    "kind",              "PIDController",
    "max_instance",      "10",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    ""
  };
// </rtc-template>

PIDController::PIDController(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    m_shmInRefThrottle("refThrottle", m_refThrottle),
    m_shmInRefRoll    ("refRoll",     m_refRoll    ),
    m_shmInRefPitch   ("refPitch",    m_refPitch   ),
    m_shmInRefYaw     ("refYaw",      m_refYaw     ),
    m_shmInSenRoll    ("senRoll",  m_senRoll ),
    m_shmInSenPitch   ("senPitch", m_senPitch),
    m_shmInSenYaw     ("senYaw",   m_senYaw  ),
    m_shmOutRotVel0("rotVel0"),
    m_shmOutRotVel1("rotVel1"),
    m_shmOutRotVel2("rotVel2"),
    m_shmOutRotVel3("rotVel3")
{
}

PIDController::~PIDController()
{
}


RTC::ReturnCode_t PIDController::onInitialize()
{
  m_shmInRefThrottle.attachTo(*this);
  m_shmInRefRoll.attachTo    (*this);
  m_shmInRefPitch.attachTo   (*this);
  m_shmInRefYaw.attachTo     (*this);
    
  m_shmInSenRoll.attachTo (*this);
  m_shmInSenPitch.attachTo(*this);
  m_shmInSenYaw.attachTo  (*this);
    
  m_shmOutRotVel0.attachTo(*this);
  m_shmOutRotVel1.attachTo(*this);
  m_shmOutRotVel2.attachTo(*this);
  m_shmOutRotVel3.attachTo(*this);
  
  return RTC::RTC_OK;
}


/*
RTC::ReturnCode_t PIDController::onFinalize()
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onExecute(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/
/*
RTC::ReturnCode_t PIDController::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


extern "C"
{
 
  void PIDControllerInit(RTC::Manager* manager)
  {
    coil::Properties profile(pidcontroller_spec);
    manager->registerFactory(profile,
                             RTC::Create<PIDController>,
                             RTC::Delete<PIDController>);
  }
  
};



