// -*- C++ -*-
/*!
 * @file  PrimitiveProvider.cpp
 * @brief ShmPortService provider
 * $Date$ 
 *
 * $Id$ 
 */
#include "PrimitiveProvider.h"
#include <iostream>

// Module specification
static const char* primitiveprovider_spec[] =
  {
    "implementation_id", "PrimitiveProvider",
    "type_name",         "PrimitiveProvider",
    "description",       "ShmPortService provider",
    "version",           "0.1",
    "vendor",            "TIRI",
    "category",          "Generic",
    "activity_type",     "PERIODIC",
    "kind",              "PrimitiveProvider",
    "max_instance",      "10",
    "language",          "C++",
    "lang_type",         "compile",
    // Configuration variables
    ""
  };


PrimitiveProvider::PrimitiveProvider(RTC::Manager* manager)
  : RTC::DataFlowComponentBase(manager),
    m_shmOutPort("shmOut")
{
}

PrimitiveProvider::~PrimitiveProvider()
{
}


RTC::ReturnCode_t PrimitiveProvider::onInitialize()
{
  m_shmOutPort.attachTo(*this);

  const int NUM_SAMPLES = 100;
  for(int i = 0; i < NUM_SAMPLES; i++){
    const long A = 500;
    const float dt = 0.1;
    m_sendingData.push_back(long(A*(sin(i*dt) + 1)));
  }
  
  return RTC::RTC_OK;
}

RTC::ReturnCode_t PrimitiveProvider::onExecute(RTC::UniqueId ec_id)
{
  static size_t idx = 0;

  if(idx < m_sendingData.size()){
    m_shmOutPort.write(m_sendingData[idx]);
    idx++;
  }
  
  return RTC::RTC_OK;
}

extern "C"
{
 
  void PrimitiveProviderInit(RTC::Manager* manager)
  {
    coil::Properties profile(primitiveprovider_spec);
    manager->registerFactory(profile,
                             RTC::Create<PrimitiveProvider>,
                             RTC::Delete<PrimitiveProvider>);
  }
  
};



